@@ -13,8 +13,8 @@ var texts = {
     clear: "Clear",
     add: "Add",
     simpleadvanced: "Simple/advanced",
-    nodeattributes: "Node attributes",
-    linkattributes: "Link attributes",
+    nodesattributes: "Node attributes",
+    linksattributes: "Link attributes",
     noitemsselected: "No items selected",
     alertnonodes: "No nodes selected! Hold shift to select nodes.",
     alertnonodestable: "No nodes selected in table!",
@@ -23,15 +23,17 @@ var texts = {
     loading: "Loading...",
     pdfexport: "PDF export",
     svgexport: "SVG export",
+	adjustsymbols: "Adjust symbols",
     showhidelabels: "Show/hide labels",
     showhidelegend: "Show/hide legend",
     showhideaxes: "Show/hide axes",
     stopresume: "Stop/resume",
+	netheatmap: "Net/heatmap",
     isolateselection: "Filter selection",
     resetfilter: "Reset filter",
     selectall: "Select all/none",
     selectneighbors: "Add neighbors",
-    egoNet: "Ego-net",
+    egoNet: "EgoNet",
     tableselection: "Matched in table",
     reset: "Reset",
     directional: "Directional arrows",
@@ -50,11 +52,14 @@ var texts = {
     subjectselect: "Event selection",
     Label: "Label",
     Group: "Group",
+	OrderA: "A Order",
+	OrderD: "D Order",
     Size: "Size",
     Color: "Color",
     Shape: "Shape",
     Width: "Width",
     Weight: "Weight",
+	Intensity: "Intensity",
     Text: "Text",
     Show: "Show",
     Hide: "Hide",
@@ -63,5 +68,9 @@ var texts = {
     diamond: "diamond",
     square: "square",
     "triangle-down": "triangle-down",
-    "triangle-up": "triangle-up"
+    "triangle-up": "triangle-up",
+	trianglesquare: "Triangle/square",
+	selectacolorscale: "Select a color scale for ",
+    selecta: "Select a ",
+	outof: "out of"
   };
