@@ -13,9 +13,9 @@ var texts = {
     clear: "Limpiar",
     add: "Añadir",
     simpleadvanced: "Simple/avanzado",
-    nodeattributes: "Attributos de nodos",
-    linkattributes: "Attributos de enlaces",
-    noitemsselected: "sin items seleccionados",
+    nodesattributes: "Atributos de nodos",
+    linksattributes: "Atributos de enlaces",
+    noitemsselected: "Sin items seleccionados",
     alertnonodes: "¡No hay nodos seleccionados! Presiona shift para seleccionar nodos.",
     alertnonodestable: "¡No hay nodos seleccionados en la tabla!",
     repulsion: "Repulsión",
@@ -23,15 +23,17 @@ var texts = {
     loading: "Cargando...",
     pdfexport: "Exportación PDF",
     svgexport: "Exportación SVG",
+	adjustsymbols: "Fijar símbolos",
     showhidelabels: "Mostrar/ocultar etiquetas",
     showhidelegend: "Mostrar/ocultar leyenda",
     showhideaxes: "Mostrar/ocultar ejes",
     stopresume: "Parar/reanudar",
+	netheatmap: "Red/mapa de color",
     isolateselection: "Filtrar selección",
     resetfilter: "Quitar filtro",
     selectall: "Seleccionar todos/ninguno",
     selectneighbors: "Añadir vecinos",
-    egoNet: "Ego-red",
+    egoNet: "EgoRed",
     tableselection: "Marcados en la tabla",
     reset: "Reiniciar",
     directional: "Direccional",
@@ -50,11 +52,14 @@ var texts = {
     subjectselect: "Selección de eventos",
     Label: "Etiqueta",
     Group: "Grupo",
+	OrderA: "A Orden",
+	OrderD: "D Orden",
     Size: "Tamaño",
     Color: "Color",
     Shape: "Forma",
     Width: "Anchura",
     Weight: "Ponderación",
+	Intensity: "Intensidad",
     Text: "Texto",
     Show: "Mostrar",
     Hide: "Ocultar",
@@ -63,5 +68,9 @@ var texts = {
     diamond: "Diamante",
     square: "Cuadrado",
     "triangle-down": "Triangulo-abajo",
-    "triangle-up": "Triangulo-arriba"
+    "triangle-up": "Triangulo-arriba",
+	trianglesquare: "Triángulo/cuadrado",
+	selectacolorscale: "Selecciona una escala de color para ",
+    selecta: "Selecciona un/una ",
+	outof: "de"
   };
